@@ -20,15 +20,6 @@ Wrappers can alter the way the build is run as well as the build output.
   :Macro: wrapper
   :Entry Point: jenkins_jobs.wrappers
 
-Example::
-
-  job:
-    name: test_job
-
-    wrappers:
-      - timeout:
-          timeout: 90
-          fail: true
 """
 
 import xml.etree.ElementTree as XML
@@ -75,6 +66,8 @@ def timeout(parser, xml_parent, data):
     :arg bool write-description: Write a message in the description
         (default false)
     :arg int timeout: Abort the build after this number of minutes (default 3)
+    :arg str timeout-var: Export an environment variable to reference the
+        timeout value (optional)
     :arg str type: Timeout type to use (default absolute)
     :arg int elastic-percentage: Percentage of the three most recent builds
         where to declare a timeout (default 0)
@@ -86,33 +79,22 @@ def timeout(parser, xml_parent, data):
      * **elastic**
      * **absolute**
 
+    Example:
 
-    Example::
+    .. literalinclude:: /../../tests/wrappers/fixtures/timeout001.yaml
 
-      wrappers:
-        - timeout:
-            timeout: 90
-            fail: true
-            type: absolute
-
-      wrappers:
-        - timeout:
-            fail: false
-            type: likely-stuck
-
-      wrappers:
-        - timeout:
-            fail: true
-            elastic-percentage: 150
-            elastic-default-timeout: 90
-            type: elastic
+    .. literalinclude:: /../../tests/wrappers/fixtures/timeout002.yaml
 
+    .. literalinclude:: /../../tests/wrappers/fixtures/timeout003.yaml
     """
     twrapper = XML.SubElement(xml_parent,
                               'hudson.plugins.build__timeout.'
                               'BuildTimeoutWrapper')
     XML.SubElement(twrapper, 'timeoutMinutes').text = str(
         data.get('timeout', 3))
+    timeout_env_var = data.get('timeout-var')
+    if timeout_env_var:
+        XML.SubElement(twrapper, 'timeoutEnvVar').text = str(timeout_env_var)
     XML.SubElement(twrapper, 'failBuild').text = str(
         data.get('fail', 'false')).lower()
     XML.SubElement(twrapper, 'writingDescription').text = str(
@@ -951,6 +933,52 @@ def delivery_pipeline(parser, xml_parent, data):
         'set-display-name', False)).lower()
 
 
+def matrix_tie_parent(parser, xml_parent, data):
+    """yaml: matrix-tie-parent
+    Tie parent to a node.
+    Requires the Jenkins `Matrix Tie Parent Plugin.
+    <https://wiki.jenkins-ci.org/display/JENKINS/Matrix+Tie+Parent+Plugin>`_
+    Note that from Jenkins version 1.532 this plugin's functionality is
+    available under the "advanced" option of the matrix project configuration.
+
+    :arg str node: Name of the node.
+
+    Example:
+
+    .. literalinclude:: /../../tests/wrappers/fixtures/matrix-tie-parent.yaml
+    """
+    mtp = XML.SubElement(xml_parent, 'matrixtieparent.BuildWrapperMtp')
+    XML.SubElement(mtp, 'labelName').text = data['node']
+
+
+def exclusion(parser, xml_parent, data):
+    """yaml: exclusion
+    Add a resource to use for critical sections to establish a mutex on. If
+    another job specifies the same resource, the second job will wait for the
+    blocked resource to become available.
+
+    Requires the Jenkins `Exclusion Plugin.
+    <https://wiki.jenkins-ci.org/display/JENKINS/Exclusion-Plugin>`_
+
+    :arg list resources: List of resources to add for exclusion
+
+    Example:
+
+    .. literalinclude:: /../../tests/wrappers/fixtures/exclusion002.yaml
+
+    """
+    exl = XML.SubElement(xml_parent,
+                         'org.jvnet.hudson.plugins.exclusion.IdAllocator')
+    exl.set('plugin', 'Exclusion')
+    ids = XML.SubElement(exl, 'ids')
+    resources = data.get('resources', [])
+    for resource in resources:
+        dit = \
+            XML.SubElement(ids,
+                           'org.jvnet.hudson.plugins.exclusion.DefaultIdType')
+        XML.SubElement(dit, 'name').text = str(resource).upper()
+
+
 class Wrappers(jenkins_jobs.modules.base.Base):
     sequence = 80
 
